==> kadu_3.0.orig.tar.bz2: kadu-3.0/plugins/autoresponder/translations/autoresponder_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Einstallungen</translation>
    </message>
    <message>
        <source>Only for the first time</source>
        <translation>Nur das erste mal</translation>
    </message>
    <message>
        <source>Respond to conferences</source>
        <translation>Antworte auf Konferenzen</translation>
    </message>
    <message>
        <source>Status invisible</source>
        <translation>Unsichtbar</translation>
    </message>
    <message>
        <source>Status busy</source>
        <translation>Beschäftigt</translation>
    </message>
    <message>
        <source>Status available</source>
        <translation>Erreichbar</translation>
    </message>
    <message>
        <source>Auto Responder</source>
        <translation>Automatische Antwort</translation>
    </message>
    <message>
        <source>Auto answer text</source>
        <translation>Automatischer Antworttext</translation>
    </message>
    <message>
        <source>Choose Status</source>
        <translation>Wähle Status</translation>
    </message>
</context>
<context>
    <name>AutoResponder</name>
    <message>
        <source>KADU AUTORESPONDER:</source>
        <translation>KADU AUTO-ANTWORT:</translation>
    </message>
</context>
<context>
    <name>AutoresponderConfigurator</name>
    <message>
        <source>I am busy.</source>
        <translation>Ich bin beschäftigt.</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/autoresponder/translations/autoresponder_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Einstallungen</translation>
    </message>
    <message>
        <source>Only for the first time</source>
        <translation>Nur das erste mal</translation>
    </message>
    <message>
        <source>Respond to conferences</source>
        <translation>Antworte auf Konferenzen</translation>
    </message>
    <message>
        <source>Status invisible</source>
        <translation>Unsichtbar</translation>
    </message>
    <message>
        <source>Status busy</source>
        <translation>Beschäftigt</translation>
    </message>
    <message>
        <source>Status available</source>
        <translation>Erreichbar</translation>
    </message>
    <message>
        <source>Auto Responder</source>
        <translation>Automatische Antwort</translation>
    </message>
    <message>
        <source>Auto answer text</source>
        <translation>Automatischer Antworttext</translation>
    </message>
    <message>
        <source>Choose Status</source>
        <translation>Wähle Status</translation>
    </message>
</context>
<context>
    <name>AutoresponderConfigurator</name>
    <message>
        <source>I am busy.</source>
        <translation>Ich bin beschäftigt.</translation>
    </message>
</context>
<context>
    <name>AutoresponderMessageFilter</name>
    <message>
        <source>KADU AUTORESPONDER:</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
